==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-session/lxqt-session/lxqt-session_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="305"/>
        <source>Crash Report</source>
        <translation>بلاغ انهيار</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="306"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>انهار &lt;b&gt;%1&lt;/b&gt; عدة مرّات. عُطّلت إعادة تشغيله الآليّة حتّى الولوج التّالي.</translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>مرحبًا في لكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;مرحبًا في لكسكيكوت&lt;/span&gt;&lt;/p&gt;&lt;p&gt;فضلًا اختر مدير النّوافذ الافتراضيّ.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>ستستطيع تغيير هذا لاحقًا عبر التّفضيلات -&gt; إعدادات النّظام -&gt; الإعدادات الأساسيّة.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>أخرى...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>اختر ما تحبّ.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-session/lxqt-session/lxqt-session_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LXQtModuleManager</name>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="309"/>
        <source>Crash Report</source>
        <translation>بلاغ انهيار</translation>
    </message>
    <message>
        <location filename="../../../src/lxqtmodman.cpp" line="310"/>
        <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
        <translation>انهار &lt;b&gt;%1&lt;/b&gt; عدة مرّات. عُطّلت إعادة تشغيله الآليّة حتّى الولوج التّالي.</translation>
    </message>
</context>
<context>
    <name>SessionApplication</name>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <source>Configuration file path.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="58"/>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/main.cpp" line="59"/>
        <source>Window manager to use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WmSelectDialog</name>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="14"/>
        <source>Welcome to LXQt</source>
        <translation>مرحبًا في لكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;مرحبًا في لكسكيكوت&lt;/span&gt;&lt;/p&gt;&lt;p&gt;فضلًا اختر مدير النّوافذ الافتراضيّ.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.ui" line="71"/>
        <source>You will be able to change this at any time through Preferences -&gt; Session Settings -&gt; Basic Settings.</source>
        <translation>ستستطيع تغيير هذا لاحقًا عبر التّفضيلات -&gt; إعدادات النّظام -&gt; الإعدادات الأساسيّة.</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="62"/>
        <source>Other ...</source>
        <translation>أخرى...</translation>
    </message>
    <message>
        <location filename="../../../src/wmselectdialog.cpp" line="63"/>
        <source>Choose your favorite one.</source>
        <translation>اختر ما تحبّ.</translation>
    </message>
</context>
</TS>
